@@ -2,7 +2,7 @@
 .. index:: Classifier Chain Learner
 
 ***************************************
-Classifier Chain Learner
+Classifier Chain Learner (``chain``)
 ***************************************
 
 
@@ -16,9 +16,9 @@ Classifier Chain Learner
     :members:
     :show-inheritance:
 
-
+***************************************
 Ensemble Classifier Chain Learner
-###################################
+***************************************
 
 
 .. index:: Multi-target Ensemble Classifier Chain Learner
@@ -74,11 +74,12 @@ class ClassifierChainLearner(orange.Learner):
         else:
             return self
 
-    def __init__(self, learner=None, name="Classifier Chain", rand=None, callback=None, class_order=None, **kwargs):
+    def __init__(self, learner=None, name="Classifier Chain", rand=None, callback=None, class_order=None, actual_values=True, **kwargs):
         self.name = name
         self.rand = rand
         self.callback = callback
         self.class_order = class_order
+        self.actual_values = actual_values
 
         if not learner:
             raise TypeError("Wrong specification, learner not defined")
@@ -136,7 +137,11 @@ class ClassifierChainLearner(orange.Learner):
             data = Orange.data.Table(domains[i], instances)
 
             classifiers[i] = learner(data, weight)
-            
+
+            if not self.actual_values:
+                for j in xrange(len(instances)):
+                    instances[j][-1] = classifiers[i](data[j])
+
             # updates domain to include class_var in features
             instances.change_domain(Orange.data.Domain(instances.domain, False, \
                 class_vars=instances.domain.class_vars))
@@ -258,12 +263,13 @@ class EnsembleClassifierChainLearner(orange.Learner):
         else:
             return self
 
-    def __init__(self, n_chains=50, sample_size=0.25, learner=None, name="Ensemble CChain", rand=None, callback=None):
+    def __init__(self, n_chains=50, sample_size=0.25, learner=None, actual_values=True, name="Ensemble CChain", rand=None, callback=None):
         self.n_chains = n_chains
         self.sample_size = sample_size
         self.name = name
         self.rand = rand
         self.callback = callback
+        self.actual_values = actual_values
 
         if not learner:
             raise TypeError("Wrong specification, learner not defined")
@@ -302,7 +308,7 @@ class EnsembleClassifierChainLearner(orange.Learner):
             self.rand.shuffle(indices)
             data = instances.select_ref(indices,1)
 
-            learner = ClassifierChainLearner(learner = self.learner, rand=self.rand) # TODO might work in one step
+            learner = ClassifierChainLearner(learner=self.learner, actual_values=self.actual_values, rand=self.rand) # TODO might work in one step
 
             classifiers.append(learner(data, weight, copy.copy(class_order)))
 
@@ -432,16 +438,23 @@ if __name__ == '__main__':
     global_timer = time.time()
     data = Orange.data.Table('multitarget:bridges.tab')
 
-    cl1 = EnsembleClassifierChainLearner(learner = Orange.classification.tree.SimpleTreeLearner, n_chains=50, sample_size=0.25, name="ECC T", rand = random.seed(time.time()))
-    cl2 = EnsembleClassifierChainLearner(learner = Orange.classification.majority.MajorityLearner, n_chains=50, sample_size=0.25, name="ECC M", rand = random.seed(time.time()))
-    cl3 = ClassifierChainLearner(learner = Orange.classification.tree.SimpleTreeLearner, name="CC T")
-    cl4 = ClassifierChainLearner(learner = Orange.classification.majority.MajorityLearner, name="CC M")
+    cl1 = ClassifierChainLearner(learner = Orange.classification.tree.SimpleTreeLearner, name="CChain - Tree")
+    cl2 = ClassifierChainLearner(learner = Orange.classification.majority.MajorityLearner, name="CChain - Maj")
+    cl3 = EnsembleClassifierChainLearner(learner = Orange.classification.tree.SimpleTreeLearner, n_chains=50, sample_size=0.25, name="Ensemble CC - Tree")
+    cl4 = EnsembleClassifierChainLearner(learner = Orange.classification.majority.MajorityLearner, n_chains=50, sample_size=0.25, name="Ensemble CC - Maj")
+    
+    learners = [cl1,cl2,cl3,cl4]
+
+    results = Orange.evaluation.testing.cross_validation(learners, data)
+
+
+    print "%18s  %6s  %8s  %8s" % ("Learner    ", "LogLoss", "Mean Acc", "Glob Acc")
+    for i in range(len(learners)):
+        print "%18s  %1.4f    %1.4f    %1.4f" % (learners[i].name,
+        Orange.multitarget.scoring.mt_average_score(results, Orange.evaluation.scoring.logloss)[i],
+        Orange.multitarget.scoring.mt_mean_accuracy(results)[i],
+        Orange.multitarget.scoring.mt_global_accuracy(results)[i])
 
-    res = Orange.evaluation.testing.cross_validation([cl1,cl2,cl3,cl4],data)
 
-    scores = Orange.multitarget.scoring.mt_average_score(res,Orange.evaluation.scoring.RMSE)
-   
-    for i in range(len(scores)):
-        print res.classifierNames[i], scores[i]
 
     print "--DONE %.2f --" % (time.time()-global_timer)
