@@ -1,14 +1,11 @@
 ﻿"""
 .. index:: Multi-target Neural Network Learner
 
-***************************************
-Multi-target Neural Network Learner
-***************************************
+********************************************************
+Multi-target Neural Network Learner (``neural``)
+********************************************************
 
-Example of multi-target  usage:
 
-.. literalinclude:: ../../_multitarget/neural.py
-    :lines: 17-
 """
 
 from Orange.classification.neural import NeuralNetworkLearner, NeuralNetworkClassifier
@@ -19,7 +16,7 @@ if __name__ == '__main__':
     print "STARTED"
     global_timer = time.time()
 
-    l = Orange.multitarget.neural.NeuralNetworkLearner()
+    l = Orange.multitarget.neural.NeuralNetworkLearner(n_mid = 20, reg_fact = 0.1, max_iter=100)
 
     data = Orange.data.Table('multitarget:emotions.tab')
     res = Orange.evaluation.testing.cross_validation([l],data, 3)
